@@ -52,6 +52,8 @@ from urlparse    import urljoin  as urlparse_urljoin
 from .          import __version__, __file__
 from .constants import CONSTANTS, _file_to_fh
 
+from . import mpi_on
+
 # Are we running on GNU/Linux?
 _linux = system() == 'Linux'
 
@@ -59,8 +61,13 @@ if _linux:
     # ----------------------------------------------------------------
     # GNU/LINUX
     # ----------------------------------------------------------------
+    # Opening /proc/meminfo once per PE here rather than in
+    # _free_memory each time it is called works with MPI on
+    # Debian-based systems, which otherwise throw an error that there
+    # is no such file or directory when run on multiple PEs.
+    # ----------------------------------------------------------------
     _meminfo_fields = set(('SReclaimable:', 'Cached:', 'Buffers:', 'MemFree:'))
-#    _meminfo_file   = open('/proc/meminfo', 'r', 1)
+    _meminfo_file   = open('/proc/meminfo', 'r', 1)
 
     def _free_memory():
         '''
@@ -91,7 +98,12 @@ longer required.
         # ----------------------------------------------------------------
         free_KiB = 0.0
         n=0
-        _meminfo_file   = open('/proc/meminfo', 'r', 1)
+        
+        # with open('/proc/meminfo', 'r', 1) as _meminfo_file:
+
+        # Seeking the beginning of the file /proc/meminfo regenerates
+        # the information contained in it.
+        _meminfo_file.seek(0)
         for line in _meminfo_file:
             field_size = line.split()
             if field_size[0] in _meminfo_fields:
@@ -100,10 +112,12 @@ longer required.
                 if n > 3:
                     break
         #--- End: for
-#        _meminfo_file.seek(0)
-        del _meminfo_file
 
-        return free_KiB * 1024
+        free_bytes = free_KiB * 1024
+        if mpi_on:
+            free_bytes /= CONSTANTS['FREE_MEMORY_FACTOR']
+
+        return free_bytes
     #--- End: def
 else:
     # ----------------------------------------------------------------
@@ -125,7 +139,11 @@ The amount of available physical memory.
 96496240.0
 
 '''
-        return float(virtual_memory().available)
+        free_bytes = float(virtual_memory().available)
+        if mpi_on:
+            free_bytes /= CONSTANTS['FREE_MEMORY_FACTOR']
+        #--- End: if
+        return free_bytes
     #--- End: def
 #--- End: if
 
@@ -417,6 +435,88 @@ True
     return old
 #--- End:def
 
+def COLLAPSE_PARALLEL_MODE(*arg):
+    '''Which mode to use when collapse is run in parallel. There are three
+possible modes:
+
+0.  This attempts to maximise parallelism, possibly at the expense of
+    extra communication. This is the default mode.
+
+1.  This minimises communication, possibly at the expense of the
+    degree of parallelism. If collapse is running slower than you
+    would expect, you can try changing to mode 1 to see if this
+    improves performance. This is only likely to work if the output of
+    collapse will be a sizeable array, not a single point.
+
+2.  This is here for debugging purposes, but we would expect this to
+    maximise communication possibly at the expense of parallelism. The
+    use of this mode is, therefore, not recommended.
+
+:Parameters:
+
+    arg: `int`, optional
+        The new value (0, 1 or 2).
+
+:Returns:
+
+    out: `int`
+        The value prior to the change, or the current value if no new
+        value was specified.
+
+:Examples:
+
+>>> cf.COLLAPSE_PARALLEL_MODE()
+0
+>>> cf.COLLAPSE_PARALLEL_MODE(1)
+0
+>>> cf.COLLAPSE_PARALLEL_MODE()
+1
+
+    '''
+    old = CONSTANTS['COLLAPSE_PARALLEL_MODE']
+    if arg:
+        if arg[0] not in (0, 1, 2):
+            raise ValueError('Invalid collapse parallel mode')
+        #--- End: if
+        CONSTANTS['COLLAPSE_PARALLEL_MODE'] = arg[0]
+    #--- End: if
+
+    return old
+#--- End: def
+
+def FREE_MEMORY_FACTOR(*arg):
+    '''The factor to divide the free memory by if MPI is on. Usually
+this is the number of PEs. If MPI is not on this is ignored.
+
+:Parameters:
+
+    arg: `int`, optional
+        The new value.
+
+:Returns:
+
+    out: `int`
+        The value prior to the change, or the current value if no new
+        value was specified.
+
+:Examples:
+
+>>> cf.FREE_MEMORY_FACTOR()
+4
+>>> cf.FREE_MEMORY_FACTOR(1)
+4
+>>> cf.FREE_MEMORY_FACTOR()
+1
+
+    '''
+    old = CONSTANTS['FREE_MEMORY_FACTOR']
+    if arg:
+        CONSTANTS['FREE_MEMORY_FACTOR'] = arg[0]
+    #--- End: if
+
+    return old
+#--- End: def
+
 def RELAXED_IDENTITIES(*arg):
     '''
 
