@@ -30,7 +30,7 @@ from ..cfdatetime      import dt2rt
 from ..coordinate      import Coordinate
 #from ..coordinatebounds import CoordinateBounds
 from ..field           import Field, FieldList
-from ..functions       import equals, flat, relpath, abspath
+from ..functions       import equals, flat, relpath, abspath, FREE_MEMORY
 
 from ..data.data       import Data
 
@@ -1845,7 +1845,7 @@ created. The ``seen`` dictionary is updated for *cfvar*.
         data = None
     else:
         data = cfvar.Data            
-        config = data.partition_configuration(readonly=True)
+#        config = data.partition_configuration(readonly=True)
 
         if datatype == 'S1':
             # --------------------------------------------------------
@@ -1859,39 +1859,61 @@ created. The ``seen`` dictionary is updated for *cfvar*.
                     
                 ncdimensions = dimensions + (ncdim,)
 
-                data = data.copy()
+#                data = data.copy()
 
-                new_axis = data._new_axis_identifier()
+                data = Data(_character_array(data.array),
+                            units=data.Units, fill_value=data.fill_value)
+                
+#                array = data.array
+#                config = data.partition_configuration(readonly=False)
+ #               
+#                new_axis = data._new_axis_identifier()
+#
+#                data._axes = data._axes + [new_axis]
+#                data._shape += (strlen,)
+#                data._ndim += 1
+#                data.dtype = datatype
+#
+#                for partition in data.partitions.flat:
+#                    print 'ppp'
+#                    partition.open(config)
+#                    array = partition.array
+#                    
+#                    # Convert the partition's string array into a
+#                    # character array. Note that it is very important
+#                    # to not change the mutable attributes of the
+#                    # partition object in-place.
+#                    if partition.part:
+#                        partition.part = partition.part + [slice(None)]
+#
+#                    partition.axes     = partition.axes + [new_axis]
+#                    partition.shape    = partition.shape + [strlen]
+#                    partition.location = partition.location + [(0, strlen)]
+#                    print partition.axes
+#                    partition.subarray = _character_array(array)
+#                    print _character_array(array)
+#                    print partition.subarray            
+##                    partition.config['axes'] = data._axes
+##                    partition.close()
+#                #--- End: for
 
-                for partition in data.partitions.flat:
-                    partition.open(config)
-                    array = partition.array
-                    
-                    # Convert the partition's string array into a
-                    # character array. Note that it is very important
-                    # to not change the mutable attributes of the
-                    # partition object in-place.
-                    if partition.part:
-                        partition.part = partition.part + [slice(None)]
+#data._axes = data._axes + [new_axis]
+#data._shape += (strlen,)
+#data._ndim += 1
+#data.dtype = datatype
+#
+#                config['axes'] = data._axes
+#                config['readonly'] = True
 
-                    partition.axes     = partition.axes + [new_axis]
-                    partition.shape    = partition.shape + [strlen]
-                    partition.location = partition.location + [(0, strlen)]
-
-                    partition.subarray    = _character_array(array)
-
-                    partition.close()
-                #--- End: for
-
-                data._axes = data._axes + [new_axis]
-                data._shape += (strlen,)
-                data._ndim += 1
-                data.dtype = datatype
-
-                config['axes'] = data._axes
 #                pda_args['keep_in_memory'] = True
+        #--- End: if
+
+        config = data.partition_configuration(readonly=True)
+
     #--- End: if
 
+    config = data.partition_configuration(readonly=True)
+
     # Find the fill value (note that this is set in the call to
     # netCDF4.createVariable, rather than with setncattr).
     fill_value = cfvar.fill_value()
@@ -1933,7 +1955,7 @@ created. The ``seen`` dictionary is updated for *cfvar*.
             chunksizes = None
 
         if _debug:
-            print '        chunksizes =', chunksizes
+            print '        chunksizes =', chunksizes, 'ncdimensions =', ncdimensions
             
         try:
             g['nc'][ncvar] = g['netcdf'].createVariable(
